import { watch } from "vue";
import { useSupabaseClient } from "../composables/useSupabaseClient.mjs";
import { useSupabaseUser } from "../composables/useSupabaseUser.mjs";
import { useSupabaseToken } from "../composables/useSupabaseToken.mjs";
import { defineNuxtPlugin, useRuntimeConfig, useRoute, navigateTo } from "#imports";
export default defineNuxtPlugin(async (nuxtApp) => {
  const user = useSupabaseUser();
  const client = useSupabaseClient();
  const redirect = useRuntimeConfig().public.supabase.redirect;
  if (!user.value) {
    const token = useSupabaseToken();
    if (token.value) {
      const { data: { user: supabaseUser }, error } = await client.auth.getUser(token.value);
      if (error) {
        token.value = null;
        user.value = null;
      } else {
        user.value = supabaseUser;
      }
    }
  }
  if (redirect && redirect.login) {
    watch(user, (newUser) => {
      if (newUser) {
        return;
      }
      const route = useRoute();
      if (route.fullPath === redirect.login) {
        return;
      }
      setTimeout(() => {
        navigateTo(redirect.login);
      }, 0);
    }, { immediate: true });
  }
  nuxtApp.hooks.hook("app:mounted", () => {
    client.auth.onAuthStateChange(async (event, session) => {
      await setServerSession(event, session);
      const userResponse = await client.auth.getUser();
      user.value = userResponse.data.user;
    });
  });
});
function setServerSession(event, session) {
  return $fetch("/api/_supabase/session", {
    method: "POST",
    body: { event, session }
  });
}
